@@ -1,9 +1,27 @@
 #include <cstring>
 #include <memory>
+#include <boost/detail/endian.hpp>
 #include <Rcpp.h>
-#include "MurmurHash3.h"
+#include "digestlocal.h"
 #include "tag.h"
 
+#ifdef linux
+#include <byteswap.h>
+#endif
+
+#ifndef bswap_32
+#ifdef __APPLE__
+#include <libkern/OSByteOrder.h>
+#else
+uint32_t bswap_32(uint32_t x) {
+  return ((x & 0xff000000) >> 24) |
+         ((x & 0x00ff0000) >>  8) |
+         ((x & 0x0000ff00) <<  8) |
+         ((x & 0x000000ff) << 24);
+}
+#endif
+#endif
+
 using namespace Rcpp;
 
 typedef std::map< std::string, std::string > NameClassMapping;
@@ -56,7 +74,7 @@ public :
   MurmurHash3HashFunction(uint32_t _seed) : seed(_seed) { }
 
   virtual uint32_t operator()(const char* buf, int size, bool is_interaction = false) {
-    return ::FeatureHashing_murmurhash3(buf, size, seed);
+    return ::PMurHash32(seed, buf, size);
   }
 };
 
@@ -91,14 +109,22 @@ public:
   { }
   
   virtual uint32_t operator()(const char* buf, int size, bool is_interaction = false) {
-    uint32_t retval = FeatureHashing_murmurhash3(buf, size, seed);
+    uint32_t retval = PMurHash32(seed, buf, size);
     if (is_interaction) {
       const uint32_t* src = reinterpret_cast<const uint32_t*>(buf);
+      #ifdef BOOST_BIG_ENDIAN
+      if (inverse_mapping.find(bswap_32(src[0])) == inverse_mapping.end()) throw std::logic_error("interaction is hashed before main effect!");
+      if (inverse_mapping.find(bswap_32(src[1])) == inverse_mapping.end()) throw std::logic_error("interaction is hashed before main effect!");
+      std::string key(inverse_mapping[bswap_32(src[0])]);
+      key.append(":");
+      key.append(inverse_mapping[bswap_32(src[1])]);
+      #else
       if (inverse_mapping.find(src[0]) == inverse_mapping.end()) throw std::logic_error("interaction is hashed before main effect!");
       if (inverse_mapping.find(src[1]) == inverse_mapping.end()) throw std::logic_error("interaction is hashed before main effect!");
       std::string key(inverse_mapping[src[0]]);
       key.append(":");
       key.append(inverse_mapping[src[1]]);
+      #endif
       e[key.c_str()] = wrap(retval);
       inverse_mapping[retval] = key;
     } 
@@ -526,8 +552,13 @@ private:
 
   uint32_t get_hashed_feature(HashFunction *h, uint32_t a, uint32_t b) {
     uint32_t buf[2];
+    #ifdef BOOST_BIG_ENDIAN
+    buf[0] = bswap_32(a);
+    buf[1] = bswap_32(b);
+    #else
     buf[0] = a;
     buf[1] = b;
+    #endif
     return (*h)(reinterpret_cast<char*>(buf), sizeof(uint32_t) * 2, true);
   }
   
@@ -561,7 +592,7 @@ const ConvertersVec get_converters(
   for(int i = 0;i < feature_name.size();i++) {
     bool is_interaction = false;
     for(int j = 0;j < reference_name.size();j++) {
-      if (tfactors(i, j) == 0) continue;
+      if (tfactors(j, i) == 0) continue;
       std::string rname(as<std::string>(reference_name[j]));
       #ifdef NOISY_DEBUG
       Rprintf("%s -> ", rname.c_str());
