@@ -1,3 +1,4 @@
+library(RUnit)
 library(Matrix)
 library(FeatureHashing)
 contr <- list(
@@ -10,7 +11,8 @@ m1 <- sparse.model.matrix(~ ., CO2, contr, transpose = TRUE)
 v <- numeric(dim(m1)[2])
 r1 <- as.vector(m1 %*% v)
 r2 <- FeatureHashing:::Xv(m1, v, numeric(dim(m1)[1]))
-stopifnot(isTRUE(all.equal(r1, r2)))
+checkTrue(isTRUE(all.equal(r1, r2)),
+          "The matrix-vector multiplication is incorrect")
 
 for(i in 1:ncol(m1)) {
   v <- numeric(dim(m1)[2])
@@ -18,7 +20,8 @@ for(i in 1:ncol(m1)) {
   r1 <- as.vector(m1 %*% v)
   r2 <- numeric(dim(m1)[1])
   FeatureHashing:::Xv(m1, v, r2)
-  stopifnot(isTRUE(all.equal(r1, r2)))
+  checkTrue(isTRUE(all.equal(r1, r2)),
+            "The result of C++ Xv is incorrect")
   r <- as.vector(m1[,i])
 }
 
@@ -26,7 +29,8 @@ for(i in 1:ncol(m1)) {
 v <- numeric(dim(m1)[1])
 r1 <- as.vector(v %*% m1)
 r2 <- FeatureHashing:::vX(v, m1, numeric(dim(m1)[2]))
-stopifnot(isTRUE(all.equal(r1, r2)))
+checkTrue(isTRUE(all.equal(r1, r2)),
+          "The result of C++ vX is incorrect")
 
 for(i in 1:nrow(m1)) {
   v <- numeric(dim(m1)[1])
@@ -34,5 +38,6 @@ for(i in 1:nrow(m1)) {
   r1 <- as.vector(v %*% m1)
   r2 <- numeric(dim(m1)[2])
   FeatureHashing:::vX(v, m1, r2)
-  stopifnot(isTRUE(all.equal(r1, r2)))
+  checkTrue(isTRUE(all.equal(r1, r2)),
+            "The result of matrix-vector multiplication is incorrect")
 }
